@@ -13,11 +13,30 @@
 # under the License.
 from oslo_config import cfg
 
-import panko.dispatcher
 import panko.storage
 import panko.utils
 
 
+STORAGE_OPTS = [
+    cfg.IntOpt('max_retries',
+               default=10,
+               deprecated_group='database',
+               help='Maximum number of connection retries during startup. '
+                    'Set to -1 to specify an infinite retry count.'),
+    cfg.IntOpt('retry_interval',
+               default=10,
+               deprecated_group='database',
+               help='Interval (in seconds) between retries of connection.'),
+    cfg.BoolOpt('es_ssl_enabled',
+                default=False,
+                help="Enable HTTPS connection in the Elasticsearch "
+                     "connection"),
+    cfg.StrOpt('es_index_name',
+               default='events',
+               help='The name of the index in Elasticsearch'),
+]
+
+
 def list_opts():
     return [
         ('DEFAULT',
@@ -36,5 +55,5 @@ def list_opts():
                         'items returned by API request.'),
          ]),
         ('database', panko.storage.OPTS),
-        ('storage', panko.dispatcher.STORAGE_OPTS),
+        ('storage', STORAGE_OPTS),
     ]
