@@ -16,7 +16,6 @@
 
 import datetime
 
-from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
 import webtest.app
 
@@ -226,7 +225,7 @@ class TestEventAPI(EventTestBase):
     def test_get_events_filter_start_timestamp(self):
         data = self.get_json(self.PATH, headers=HEADERS,
                              q=[{'field': 'start_timestamp',
-                                 'op': 'ge',
+                                 'op': 'eq',
                                  'value': '2014-01-01T00:00:00'}])
         self.assertEqual(2, len(data))
         sorted_types = sorted([d['event_type'] for d in data])
@@ -241,14 +240,14 @@ class TestEventAPI(EventTestBase):
                              expect_errors=True)
         self.assertEqual(400, resp.status_code)
         self.assertEqual(u'Operator gt is not supported. Only'
-                         ' `ge\' operator is available for field'
+                         ' `eq\' operator is available for field'
                          ' start_timestamp',
                          resp.json['error_message']['faultstring'])
 
     def test_get_events_filter_end_timestamp(self):
         data = self.get_json(self.PATH, headers=HEADERS,
                              q=[{'field': 'end_timestamp',
-                                 'op': 'le',
+                                 'op': 'eq',
                                  'value': '2014-01-03T00:00:00'}])
         self.assertEqual(3, len(data))
         event_types = ['Foo', 'Bar', 'Zoo']
@@ -263,17 +262,17 @@ class TestEventAPI(EventTestBase):
                              expect_errors=True)
         self.assertEqual(400, resp.status_code)
         self.assertEqual(u'Operator gt is not supported. Only'
-                         ' `le\' operator is available for field'
+                         ' `eq\' operator is available for field'
                          ' end_timestamp',
                          resp.json['error_message']['faultstring'])
 
     def test_get_events_filter_start_end_timestamp(self):
         data = self.get_json(self.PATH, headers=HEADERS,
                              q=[{'field': 'start_timestamp',
-                                 'op': 'ge',
+                                 'op': 'eq',
                                  'value': '2014-01-02T00:00:00'},
                                 {'field': 'end_timestamp',
-                                 'op': 'le',
+                                 'op': 'eq',
                                  'value': '2014-01-03T10:00:00'}])
         self.assertEqual(1, len(data))
         sorted_types = sorted([d['event_type'] for d in data])
@@ -638,6 +637,20 @@ class AclRestrictedEventTestBase(v2.FunctionalTest):
         data = self.get_json('/events/2', headers=a_headers)
         self.assertEqual('admin_ev', data['event_type'])
 
+    @tests_db.run_with('sqlite', 'mysql', 'pgsql', 'mongodb', 'es')
+    def test_admin_access_all(self):
+        a_headers = {"X-Roles": "admin",
+                     "X-User-Id": self.admin_user_id,
+                     "X-Project-Id": self.admin_proj_id}
+        data = self.get_json('/events', headers=a_headers,
+                             q=[{'field': 'all_tenants',
+                                 'value': 'True',
+                                 'type': 'string',
+                                 'op': 'eq'}])
+        self.assertEqual(3, len(data))
+        self.assertEqual(set(['empty_ev', 'admin_ev', 'user_ev']),
+                         set(ev['event_type'] for ev in data))
+
     @tests_db.run_with('sqlite', 'mysql', 'pgsql', 'mongodb', 'es')
     def test_admin_access_trait_filter_no_access(self):
         a_headers = {"X-Roles": "admin",
@@ -748,7 +761,7 @@ class TestEventSort(EventTestBase):
                          "':', or only sort key specified and sort dir will "
                          "be default 'asc', the supported sort keys are: "
                          "('message_id', 'generated')",
-                         jsonutils.loads(resp.body)['error_message']
+                         resp.json['error_message']
                          ['faultstring'])
 
     def test_invalid_sort_dir(self):
@@ -762,7 +775,7 @@ class TestEventSort(EventTestBase):
                          "with ':', or only sort key specified and sort dir "
                          "will be default 'asc', the supported sort "
                          "directions are: ('asc', 'desc')",
-                         jsonutils.loads(resp.body)['error_message']
+                         resp.json['error_message']
                          ['faultstring'])
 
     def test_sort_message_id(self):
