@@ -105,6 +105,15 @@ class EventTest(EventTestBase):
             self.assertEqual(2, log.exception.call_count)
 
 
+class BigIntegerTest(EventTestBase):
+    def test_trait_bigint(self):
+        big = 99999999999999
+        new_events = [models.Event(
+            "id_testid", "MessageIDTest", self.start,
+            [models.Trait('int', models.Trait.INT_TYPE, big)], {})]
+        self.conn.record_events(new_events)
+
+
 class GetEventTest(EventTestBase):
 
     def test_generated_is_datetime(self):
@@ -340,8 +349,8 @@ class GetEventTest(EventTestBase):
 
     def test_get_event_multiple_trait_filter(self):
         trait_filters = [{'key': 'trait_B', 'integer': 1},
-                         {'key': 'trait_A', 'string': 'my_Foo_text'},
-                         {'key': 'trait_C', 'float': 0.123456}]
+                         {'key': 'trait_C', 'float': 0.123456},
+                         {'key': 'trait_A', 'string': 'my_Foo_text'}]
         event_filter = storage.EventFilter(self.start, self.end,
                                            traits_filter=trait_filters)
         events = [event for event in self.conn.get_events(event_filter)]
